;==============================================================
; Helper functions
;==============================================================

SetVDPAddress:
; Sets the VDP address
; Parameters: hl = address
; Affects: a
    ld a,l
    out (VDPControl),a
    ld a,h
    out (VDPControl),a
    ret

CopyToVDP:
; Copies data to the VDP
; Parameters: hl = data address, bc = data length
; Affects: a, hl, bc
-:  ld a,(hl)    ; Get data byte
    out (VDPData),a
    inc hl       ; Point to next byte
    dec bc
    ld a,b
    or c
    jr nz,-
    ret

CountBoard:
; Counts variable board_counter from 0 to 63
; Affects: a
    ld a, (board_counter)
    inc a
    cp 64
    jr nz,+
    xor a
+:  ld (board_counter), a
    ret

CountSound:
    ld a, (sound_counter)
    inc a
    ld (sound_counter), a
    ret

StrikeSound:
    push af
         ld a, $F0
         out (PSGSetup), a
         xor a
         ld (sound_counter), a
-:       ld a,(sound_counter)
         cp 30
         jr nz,-
         ld a, $FF
         out (PSGSetup), a
    pop af
    ret
    
MissSound:
    push af
         ld a, $B5
         out (PSGSetup), a
         xor a
         ld (sound_counter), a
-:       ld a,(sound_counter)
         cp 20
         jr nz,-
         ld a, $BF
         out (PSGSetup), a
    pop af
    ret
    
DrawCrosshair:
    ; Set VRAM write address to start of x coordinates and tile indexes
    ld hl,$3F80 | VRAMWrite
    call SetVDPAddress

    ld a,(crosshair_x)     ;Set x coordinate
    out (VDPData), a
    ld a, $1B              ;Set tile number (Cross)
    out (VDPData), a

    ; Set VRAM write address to start of y coordinates
    ld hl,$3F00 | VRAMWrite
    call SetVDPAddress

    ld a,(crosshair_y)
    out (VDPData), a       ;Set y coordinate
    ret
    
DrawHole:
    ld a, $33
    out (VDPData), a
    xor a
    out (VDPData), a
    ret
    
PrintPlayerBoard:
    ld hl, $3908 | VRAMWrite
    call SetVDPAddress
    ld de, player_board
    call NextBoardLine

    ld b, 7
-:  push bc
         ld bc, 64
         add hl, bc
         call SetVDPAddress
         call NextBoardLine
    pop bc
    djnz -
    ret

    NextBoardLine:
    ld b, 8
-:  ld a, (de)
    and %00111111
    cp 1
    jr nz,+
    ld a, $0D
    out (VDPData), a
    jp ++

+:  cp 2
    jr nz,+
    ld a, $0E
    out (VDPData), a
    jp ++

+:  cp 3
    jr nz,+
    ld a, $0F
    out (VDPData), a
    jp ++
    
+:  cp 4
    jr nz,+
    ld a, $10
    out (VDPData), a
    jp ++
    
+:  cp 5
    jr nz,+
    ld a, $10
    out (VDPData), a
    jp ++

+:  cp 6
    jr nz,+
    ld a, $15
    out (VDPData), a
    jp ++
    
+:  cp 7
    jr nz,+
    ld a, $15
    out (VDPData), a
    jp ++
    
+:  ld a, $04
    out (VDPData), a

++: xor a
    out (VDPData), a
    inc de
    djnz -
    ret
