;==============================================================
; Set up VDP registers
;==============================================================
    ld hl,VDPInitData
    ld b,VDPInitDataEnd-VDPInitData
    ld c,VDPControl
    otir

;==============================================================
; Clear VRAM
;==============================================================
    ; 1. Set VRAM write address to $0000
    ld hl,$0000 | VRAMWrite
    call SetVDPAddress

    ; 2. Output 16KB of zeroes
    ld bc,$4000     ; Counter for 16KB of VRAM
-:  xor a
    out (VDPData),a ; Output to VRAM address, which is auto-incremented after each write
    dec bc
    ld a,b
    or c
    jr nz,-

;==============================================================
; Load palette
;==============================================================
    ; 1. Set VRAM write address to CRAM (palette) address 0
    ld hl,$0000 | CRAMWrite
    call SetVDPAddress

    ; 2. Output colour data
    ld hl,PaletteData
    ld bc,PaletteDataEnd-PaletteData
    call CopyToVDP

;==============================================================
; Load tiles
;==============================================================
    ; 1. Set VRAM write address to tile index 0
    ld hl,$0000 | VRAMWrite
    call SetVDPAddress

    ; 2. Output tile data
    ld hl,TileData              ; Location of tile data
    ld bc,TileDataEnd-TileData  ; Counter for number of bytes to write
    call CopyToVDP

;==============================================================
; Write first background to name table
;==============================================================
    ; 1. Set VRAM write address to tilemap index 0
    ld hl,$3800 | VRAMWrite
    call SetVDPAddress

    ; 2. Output background data
    ld hl,FirstBackgroundData
    ld bc,SecondBackgroundData-FirstBackgroundData  ; Counter for number of bytes to write
    call CopyToVDP
    
;==============================================================
; Clear the boards
;==============================================================
    ; Clear boards
    ld hl, player_board
    ld b, 64
-:  ld (hl), 0
    inc hl
    djnz -

    ld hl, enemy_board
    ld b, 64
-:  ld (hl), 0
    inc hl
    djnz -
    
    ; Clear counter
    xor a
    ld (board_counter), a
    
;==============================================================
; Give life to the ships and players
;==============================================================
    ld a, 5
    ld (enemy_air), a
    ld (player_air), a
    dec a
    ld (enemy_bat), a
    ld (player_bat), a
    dec a
    ld (enemy_cru), a
    ld (player_cru), a
    dec a
    ld (enemy_des_1), a
    ld (enemy_des_2), a
    ld (player_des_1), a
    ld (player_des_2), a
    dec a
    ld (enemy_sub_1), a
    ld (enemy_sub_2), a
    ld (player_sub_1), a
    ld (player_sub_2), a
    ld a, 7
    ld (enemy_ships), a
    ld (player_ships), a

;==============================================================
; Set sound
;==============================================================

    ; Channel 1 frequency
    ld a, $A0
    out (PSGSetup), a
    ld a, $20
    out (PSGSetup), a

    ; Channel 2 frequency
    ld a, $C0
    out (PSGSetup), a
    ld a, $11
    out (PSGSetup), a

    ; Noise
    ld a, $E7
    out (PSGSetup), a